==> genometools_1.5.1.orig.tar.gz: genometools-1.5.1/gtpython/gt/extended/anno_db.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
# Copyright (c) 2012 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from gt.dlload import gtlib
from gt.core.error import Error, gterror
from gt.extended.rdb import RDB
from gt.annotationsketch.feature_index import FeatureIndexFromPtr


class AnnoDBSchema:

    def __init__(self, *args):
        raise NotImplementedError, \
            'Please call the constructor of an AnnoDBSchema implementation.'

    def __del__(self):
        try:
            gtlib.gt_anno_db_schema_delete(self.ads)
        except AttributeError:
            pass

    def from_param(cls, obj):
        if not isinstance(obj, AnnoDBSchema):
            raise TypeError, "argument must be an AnnoDBSchema"
        return obj._as_parameter_

    from_param = classmethod(from_param)

    def get_feature_index(self, rdb):
        err = Error()
        fi = gtlib.gt_anno_db_schema_get_feature_index(self.ads, rdb, err)
        if fi == None:
            gterror(err)
        return FeatureIndexFromPtr(fi)

    def register(cls, gtlib):
        from ctypes import c_void_p
        gtlib.gt_anno_db_schema_get_feature_index.restype = c_void_p
        gtlib.gt_anno_db_schema_get_feature_index.argtypes = [c_void_p, RDB, Error]

    register = classmethod(register)

class AnnoDBGFFLike(AnnoDBSchema):

    def __init__(self):
        err = Error()
        ads = gtlib.gt_anno_db_gfflike_new()
        if ads == None:
            gterror(err)
        self.ads = ads
        self._as_parameter_ = self.ads

    def from_param(cls, obj):
        if not isinstance(obj, AnnoDBGFFLike):
            raise TypeError, "argument must be an AnnoDBGFFLike"
        return obj._as_parameter_

    from_param = classmethod(from_param)

    def register(cls, gtlib):
        from ctypes import c_void_p
        gtlib.gt_anno_db_gfflike_new.restype = c_void_p

    register = classmethod(register)

==> genometools_1.5.6.orig.tar.gz: genometools-1.5.6/gtpython/gt/extended/anno_db.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright (c) 2014 Daniel Standage <daniel.standage@gmail.com>
# Copyright (c) 2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
# Copyright (c) 2012 Center for Bioinformatics, University of Hamburg
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from gt.dlload import gtlib
from gt.core.error import Error, gterror
from gt.extended.rdb import RDB
from gt.annotationsketch.feature_index import FeatureIndexFromPtr


class AnnoDBSchema:

    def __init__(self, *args):
        raise NotImplementedError, \
            'Please call the constructor of an AnnoDBSchema implementation.'

    def __del__(self):
        try:
            gtlib.gt_anno_db_schema_delete(self.ads)
        except AttributeError:
            pass

    def from_param(cls, obj):
        if not isinstance(obj, AnnoDBSchema):
            raise TypeError, "argument must be an AnnoDBSchema"
        return obj._as_parameter_

    from_param = classmethod(from_param)

    def get_feature_index(self, rdb):
        err = Error()
        fi = gtlib.gt_anno_db_schema_get_feature_index(self.ads, rdb._as_parameter_,
                err._as_parameter_)
        if fi == None:
            gterror(err)
        return FeatureIndexFromPtr(fi)

    def register(cls, gtlib):
        from ctypes import c_void_p
        gtlib.gt_anno_db_schema_get_feature_index.restype = c_void_p
        gtlib.gt_anno_db_schema_get_feature_index.argtypes = [c_void_p, c_void_p,
                c_void_p]
        gtlib.gt_anno_db_schema_delete.restype = None
        gtlib.gt_anno_db_schema_delete.argtypes = [c_void_p]

    register = classmethod(register)

class AnnoDBGFFLike(AnnoDBSchema):

    def __init__(self):
        err = Error()
        ads = gtlib.gt_anno_db_gfflike_new()
        if ads == None:
            gterror(err)
        self.ads = ads
        self._as_parameter_ = self.ads

    def from_param(cls, obj):
        if not isinstance(obj, AnnoDBGFFLike):
            raise TypeError, "argument must be an AnnoDBGFFLike"
        return obj._as_parameter_

    from_param = classmethod(from_param)

    def register(cls, gtlib):
        from ctypes import c_void_p
        gtlib.gt_anno_db_gfflike_new.restype = c_void_p
        gtlib.gt_anno_db_gfflike_new.argtypes = []

    register = classmethod(register)
